from .core.hints import (Box,
                         Contour,
                         Empty,
                         Linear,
                         Maybe,
                         Mix,
                         Multipoint,
                         Multipolygon,
                         Multisegment,
                         Point,
                         Polygon,
                         Scalar,
                         Segment,
                         Shaped)

Box = Box
Contour = Contour
Empty = Empty
Linear = Linear
Maybe = Maybe
Mix = Mix
Multipoint = Multipoint
Multipolygon = Multipolygon
Multisegment = Multisegment
Point = Point
Polygon = Polygon
Scalar = Scalar
Segment = Segment
Shaped = Shaped
